[PATCH 7/8] qla2xxx/tcm_qla2xxx: Rename qla_tgt_2xxx_xmit_response() function.

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



From: Madhuranath Iyengar <mni@xxxxxxxxxxxxxxx>

Signed-off-by: Madhuranath Iyengar <mni@xxxxxxxxxxxxxxx>
---
 drivers/scsi/qla2xxx/qla_target.c               |    4 ++--
 drivers/scsi/qla2xxx/qla_target.h               |    2 +-
 drivers/target/tcm_qla2xxx/tcm_qla2xxx_fabric.c |    8 ++++----
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/drivers/scsi/qla2xxx/qla_target.c b/drivers/scsi/qla2xxx/qla_target.c
index be3f8ca..27d20d7 100644
--- a/drivers/scsi/qla2xxx/qla_target.c
+++ b/drivers/scsi/qla2xxx/qla_target.c
@@ -2387,7 +2387,7 @@ static void qla_tgt_check_srr_debug(struct qla_tgt_cmd *cmd, int *xmit_type)
 static inline void qla_tgt_check_srr_debug(struct qla_tgt_cmd *cmd, int *xmit_type) {}
 #endif
 
-int qla_tgt_2xxx_xmit_response(struct qla_tgt_cmd *cmd, int xmit_type, uint8_t scsi_status)
+int qla_tgt_xmit_response(struct qla_tgt_cmd *cmd, int xmit_type, uint8_t scsi_status)
 {
 	qla_tgt_check_srr_debug(cmd, &xmit_type);
 
@@ -2400,7 +2400,7 @@ int qla_tgt_2xxx_xmit_response(struct qla_tgt_cmd *cmd, int xmit_type, uint8_t s
 		__qla_tgt_24xx_xmit_response(cmd, xmit_type, scsi_status) :
 		__qla_tgt_2xxx_xmit_response(cmd, xmit_type, scsi_status);
 }
-EXPORT_SYMBOL(qla_tgt_2xxx_xmit_response);
+EXPORT_SYMBOL(qla_tgt_xmit_response);
 
 static void qla_tgt_24xx_init_ctio_ret_entry(ctio7_to_24xx_entry_t *ctio,
 	struct qla_tgt_prm *prm)
diff --git a/drivers/scsi/qla2xxx/qla_target.h b/drivers/scsi/qla2xxx/qla_target.h
index 9ba2173..295bf1b 100644
--- a/drivers/scsi/qla2xxx/qla_target.h
+++ b/drivers/scsi/qla2xxx/qla_target.h
@@ -1132,7 +1132,7 @@ extern void qla_tgt_24xx_atio_pkt_all_vps(struct scsi_qla_host *,
 	atio7_from_24xx_entry_t *);
 extern void qla_tgt_response_pkt_all_vps(struct scsi_qla_host *, response_t *);
 extern int qla_tgt_rdy_to_xfer(struct qla_tgt_cmd *);
-extern int qla_tgt_2xxx_xmit_response(struct qla_tgt_cmd *, int, uint8_t);
+extern int qla_tgt_xmit_response(struct qla_tgt_cmd *, int, uint8_t);
 extern void qla_tgt_xmit_tm_rsp(struct qla_tgt_mgmt_cmd *);
 extern void qla_tgt_free_mcmd(struct qla_tgt_mgmt_cmd *);
 extern void qla_tgt_free_cmd(struct qla_tgt_cmd *cmd);
diff --git a/drivers/target/tcm_qla2xxx/tcm_qla2xxx_fabric.c b/drivers/target/tcm_qla2xxx/tcm_qla2xxx_fabric.c
index 83e2605..a09a9da 100644
--- a/drivers/target/tcm_qla2xxx/tcm_qla2xxx_fabric.c
+++ b/drivers/target/tcm_qla2xxx/tcm_qla2xxx_fabric.c
@@ -728,7 +728,7 @@ int tcm_qla2xxx_handle_cmd(scsi_qla_host_t *vha, struct qla_tgt_cmd *cmd,
 		 * Clear qla_tgt_cmd->locked_rsp as ha->hardware_lock
 		 * is already held here, and we'll end up calling back
 		 * into ->queue_status (tcm_qla2xxx_queue_status())
-		 * and hence qla2xxx_xmit_response().
+		 * and hence qla_tgt_xmit_response().
 		 */
 		cmd->locked_rsp = 0;
 
@@ -886,7 +886,7 @@ int tcm_qla2xxx_queue_data_in(struct se_cmd *se_cmd)
 	/*
 	 * Now queue completed DATA_IN the qla2xxx LLD and response ring
 	 */
-	return qla_tgt_2xxx_xmit_response(cmd, QLA_TGT_XMIT_DATA|QLA_TGT_XMIT_STATUS,
+	return qla_tgt_xmit_response(cmd, QLA_TGT_XMIT_DATA|QLA_TGT_XMIT_STATUS,
 				se_cmd->scsi_status);
 }
 
@@ -905,7 +905,7 @@ int tcm_qla2xxx_queue_status(struct se_cmd *se_cmd)
 	if (se_cmd->data_direction == DMA_FROM_DEVICE) {
 		/*
 		 * For FCP_READ with CHECK_CONDITION status, clear cmd->bufflen
 		 * for qla2xxx_xmit_response LLD code
 		 */
 		se_cmd->se_cmd_flags |= SCF_UNDERFLOW_BIT;
 		se_cmd->residual_count = se_cmd->data_length;
@@ -915,7 +915,7 @@ int tcm_qla2xxx_queue_status(struct se_cmd *se_cmd)
 	/*
 	 * Now queue status response to qla2xxx LLD code and response ring
 	 */
-	return qla_tgt_2xxx_xmit_response(cmd, xmit_type, se_cmd->scsi_status);
+	return qla_tgt_xmit_response(cmd, xmit_type, se_cmd->scsi_status);
 }
 
 int tcm_qla2xxx_queue_tm_rsp(struct se_cmd *se_cmd)
@@ -905,7 +905,7 @@ int tcm_qla2xxx_queue_status(struct se_cmd *se_cmd)
 		/*
 		 * For FCP_READ with CHECK_CONDITION status, clear cmd->bufflen
-		 * for qla2xxx_xmit_response LLD code
+		 * for qla_tgt_xmit_response LLD code
 		 */
 		se_cmd->se_cmd_flags |= SCF_UNDERFLOW_BIT;
-- 
1.7.7

--
To unsubscribe from this list: send the line "unsubscribe target-devel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Linux SCSI]     [Kernel Newbies]     [Linux SCSI Target Infrastructure]     [Share Photos]     [IDE]     [Security]     [Git]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux ATA RAID]     [Linux IIO]     [Device Mapper]

  Powered by Linux